Documentação da APIv1

Request Token

Token

Esse POST gera o token necessário para autenticação das chamadas na API

    curl --location --request POST 'http://parema.com.br/token' \
    --header 'Content-Type: application/x-www-form-urlencoded' \
    --data-urlencode 'username=999' \
    --data-urlencode 'password=64134651243651243654' \
    --data-urlencode 'grant_type=password'

Request Status

Status

Esse GET é apenas para teste de funcionalidade da API


    curl --location --request GET 'http://parema.com.br/apiv1/status' \    
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Request ProdutoTexto

ProdutoTexto/list

Esse GET retorna os textos, cadastrados, de um produto


    curl --location --request GET 'http://parema.com.br/apiv1/produtotexto/list?produto=[CODIGO_PRODUTO]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

ProdutoTexto/get

Esse GET retorna os textos, cadastrados, de um produto e tipo de texto


    curl --location --request GET 'http://parema.com.br/apiv1/produtotexto/get?produto=[CODIGO_PRODUTO]&tipoTexto=[TIPO_TEXTO]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Request ProdutoGrupo

ProdutoGrupo/list

Esse GET retorna os grupos, cadastrados


    curl --location --request GET 'http://parema.com.br/apiv1/produtogrupo/list' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

ProdutoGrupo/list

Esse GET retorna os grupos, cadastrados

O parâmetro web=1 são apenas os grupos configurados para aparecerem na internet

O parâmetro web=0 são os grupos configurados para NÃO aparecerem na internet


    curl --location --request GET 'http://parema.com.br/apiv1/produtogrupo/list?web=[0_ou_1]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

ProdutoGrupo/list

Esse GET retorna o grupo


    curl --location --request GET 'http://parema.com.br/apiv1/produtogrupo/get?codigo=[CODIGO_GRUPO]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

ProdutoGrupo/list

Esse GET retorna o grupo


    curl --location --request GET 'http://parema.com.br/apiv1/produtogrupo/get_bynivel?nivel=[STRING_CODIGO_NIVEL]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Request Produto

Produto/List

Esse GET retorna os produtos, cadastrados


    curl --location --request GET 'http://parema.com.br/apiv1/produto/list' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Produto/List

Esse GET retorna os produtos, cadastrados

Parâmetro data deve ser no formato YYYY-MM-DDThh:mm:ss.fff ex: 2021-01-29T07:55:46.757

Parâmetro data deve ser no formato YYYY-MM-DDThh:mm:ss ex: 2021-01-29T07:55:46

Parâmetro data deve ser no formato YYYY-MM-DD ex: 2021-01-29

Parâmetro datainicial é opcional


    curl --location --request GET 'http://parema.com.br/apiv1/produto/list?datainicial=[DATA]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Produto/List

Esse GET retorna os produtos, cadastrados

Parâmetro ativo deve ser True ou False


    curl --location --request GET 'http://parema.com.br/apiv1/produto/list?ativo=[TRUE_OU_FALSE]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Produto/List

Esse GET retorna os produtos, cadastrados

Parâmetro ativo deve ser True ou False

Parâmetro data deve ser no formato YYYY-MM-DDThh:mm:ss.fff ex: 2021-01-29T07:55:46.757

Parâmetro data deve ser no formato YYYY-MM-DDThh:mm:ss ex: 2021-01-29T07:55:46

Parâmetro data deve ser no formato YYYY-MM-DD ex: 2021-01-29

Parâmetro datainicial é opcional


    curl --location --request GET 'http://parema.com.br/apiv1/produto/list?ativo=[TRUE_OU_FALSE]&datainicial=[DATA]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Produto/Get

Esse GET retorna o produto, cadastrado

Parâmetro código deve ser numérico


    curl --location --request GET 'http://parema.com.br/apiv1/produto/get?codigo=[CODIGO_PRODUTO]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Produto/Verify

Esse GET retorna o produto, cadastrado, e todo o estatus do produto. Pode ser usado para validação antes do pedido.

Parâmetro código deve ser numérico


    curl --location --request GET 'http://parema.com.br/apiv1/produto/verify?codigo=[CODIGO_PRODUTO]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Request Produto Arquivo

ProdutoArquivo/List

Esse GET retorna os arquivos dos produtos, cadastrados

Parâmetro código do produto deve ser numérico


    curl --location --request GET 'http://parema.com.br/apiv1/produtoarquivo/list?codigo=[CODIGO_PRODUTO]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

ProdutoArquivo/List

Esse GET retorna os arquivos dos produtos, cadastrados

Parâmetro código do produto deve ser numérico

Parâmetro código do tipo deve ser numérico


    curl --location --request GET 'http://parema.com.br/apiv1/produtoarquivo/list?codigo=[CODIGO_PRODUTO]&tipo=[CODIGO_TIPO]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

ProdutoEstoquePreco/List

Esse GET retorna os estoques e preços dos produtos, cadastrados

Parâmetro produtos deve ser numérico

Parâmetro produtos pode ser uma lista numérica separada por vírgula

Parâmetro datainicial deve ser no formato YYYY-MM-DDThh:mm:ss.fff ex: 2021-01-29T07:55:46.757

Parâmetro datainicial deve ser no formato YYYY-MM-DDThh:mm:ss ex: 2021-01-29T07:55:46

Parâmetro datainicial deve ser no formato YYYY-MM-DD ex: 2021-01-29

Parâmetro datainicial é opcional

Parâmetro produtos é opcional


    curl --location --request GET 'http://parema.com.br/apiv1/produtoestoquepreco/list?produtos=[CODIGO_PRODUTO_OU_LISTA]&datainicial=[DATA]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Request Produto Lote

ProdutoLote/Get

Esse GET retorna os lotes disponíveis de um produto.

Parâmetro produto deve ser numérico


    curl --location --request GET 'http://parema.com.br/apiv1/produtolote/get?produto=[CODIGO_PRODUTO]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

    {
    "statusCode": 200,
    "message": "Produto Lotes",
    "content": [
        {
            "produto": 10296,
            "produtoNome": "CABO AL.   DUPLEX 1X10+10,00MM XLPE PRETO C/ NEUTRO NU   (METRO) - 10296",
            "lote": "39899",
            "validade": "",
            "fabricacao": "",
            "ordem": 0,
            "quantidade": 2000,
            "quantidadeNova": 2000,
            "quantidadeEntrou": 2000,
            "quantidadeFabricado": 0,
            "obs": "FI",
            "dataNota": "2025-03-28 00:00:00.000",
            "fornecedor": "INTELLI",
            "situacao": "NOVO - 2000/2000 - INTELLI"
        },
        {
            "produto": 10296,
            "produtoNome": "CABO AL.   DUPLEX 1X10+10,00MM XLPE PRETO C/ NEUTRO NU   (METRO) - 10296",
            "lote": "40260",
            "validade": "",
            "fabricacao": "",
            "ordem": 0,
            "quantidade": 3000,
            "quantidadeNova": 3000,
            "quantidadeEntrou": 3000,
            "quantidadeFabricado": 0,
            "obs": "FC",
            "dataNota": "2025-05-05 00:00:00.000",
            "fornecedor": "COPPERFIO",
            "situacao": "NOVO - 3000/3000 - COPPERFIO"
        },
        {
            "produto": 10296,
            "produtoNome": "CABO AL.   DUPLEX 1X10+10,00MM XLPE PRETO C/ NEUTRO NU   (METRO) - 10296",
            "lote": "40725",
            "validade": "",
            "fabricacao": "",
            "ordem": 0,
            "quantidade": 3000,
            "quantidadeNova": 3000,
            "quantidadeEntrou": 3000,
            "quantidadeFabricado": 0,
            "obs": "FC",
            "dataNota": "2025-06-09 00:00:00.000",
            "fornecedor": "COPPERFIO",
            "situacao": "NOVO - 3000/3000 - COPPERFIO"
        },
        {
            "produto": 10296,
            "produtoNome": "CABO AL.   DUPLEX 1X10+10,00MM XLPE PRETO C/ NEUTRO NU   (METRO) - 10296",
            "lote": "40376",
            "validade": "",
            "fabricacao": "",
            "ordem": 0,
            "quantidade": 21,
            "quantidadeNova": 21,
            "quantidadeEntrou": 3000,
            "quantidadeFabricado": 0,
            "obs": "R",
            "dataNota": "2025-05-12 00:00:00.000",
            "fornecedor": "NEOALUMINIO IND. COM. DE METAIS LTDA",
            "situacao": "RESTO - 21/3000 - NEOALUMINIO IND. COM. DE METAIS LTDA"
        },
        {
            "produto": 10296,
            "produtoNome": "CABO AL.   DUPLEX 1X10+10,00MM XLPE PRETO C/ NEUTRO NU   (METRO) - 10296",
            "lote": "40724",
            "validade": "",
            "fabricacao": "",
            "ordem": 0,
            "quantidade": 3000,
            "quantidadeNova": 3000,
            "quantidadeEntrou": 3000,
            "quantidadeFabricado": 0,
            "obs": "FC",
            "dataNota": "2025-06-09 00:00:00.000",
            "fornecedor": "COPPERFIO",
            "situacao": "NOVO - 3000/3000 - COPPERFIO"
        },
        {
            "produto": 10296,
            "produtoNome": "CABO AL.   DUPLEX 1X10+10,00MM XLPE PRETO C/ NEUTRO NU   (METRO) - 10296",
            "lote": "40726",
            "validade": "",
            "fabricacao": "",
            "ordem": 0,
            "quantidade": 3000,
            "quantidadeNova": 3000,
            "quantidadeEntrou": 3000,
            "quantidadeFabricado": 0,
            "obs": "FC",
            "dataNota": "2025-06-09 00:00:00.000",
            "fornecedor": "COPPERFIO",
            "situacao": "NOVO - 3000/3000 - COPPERFIO"
        },
        {
            "produto": 10296,
            "produtoNome": "CABO AL.   DUPLEX 1X10+10,00MM XLPE PRETO C/ NEUTRO NU   (METRO) - 10296",
            "lote": "39898",
            "validade": "",
            "fabricacao": "",
            "ordem": 0,
            "quantidade": 2000,
            "quantidadeNova": 2000,
            "quantidadeEntrou": 2000,
            "quantidadeFabricado": 0,
            "obs": "FI",
            "dataNota": "2025-03-28 00:00:00.000",
            "fornecedor": "INTELLI",
            "situacao": "NOVO - 2000/2000 - INTELLI"
        },
        {
            "produto": 10296,
            "produtoNome": "CABO AL.   DUPLEX 1X10+10,00MM XLPE PRETO C/ NEUTRO NU   (METRO) - 10296",
            "lote": "40728",
            "validade": "",
            "fabricacao": "",
            "ordem": 0,
            "quantidade": 3000,
            "quantidadeNova": 3000,
            "quantidadeEntrou": 3000,
            "quantidadeFabricado": 0,
            "obs": "FC",
            "dataNota": "2025-06-09 00:00:00.000",
            "fornecedor": "COPPERFIO",
            "situacao": "NOVO - 3000/3000 - COPPERFIO"
        },
        {
            "produto": 10296,
            "produtoNome": "CABO AL.   DUPLEX 1X10+10,00MM XLPE PRETO C/ NEUTRO NU   (METRO) - 10296",
            "lote": "40261",
            "validade": "",
            "fabricacao": "",
            "ordem": 0,
            "quantidade": 3000,
            "quantidadeNova": 3000,
            "quantidadeEntrou": 3000,
            "quantidadeFabricado": 0,
            "obs": "FC",
            "dataNota": "2025-05-05 00:00:00.000",
            "fornecedor": "COPPERFIO",
            "situacao": "NOVO - 3000/3000 - COPPERFIO"
        },
        {
            "produto": 10296,
            "produtoNome": "CABO AL.   DUPLEX 1X10+10,00MM XLPE PRETO C/ NEUTRO NU   (METRO) - 10296",
            "lote": "40374",
            "validade": "",
            "fabricacao": "",
            "ordem": 0,
            "quantidade": 24,
            "quantidadeNova": 24,
            "quantidadeEntrou": 3000,
            "quantidadeFabricado": 0,
            "obs": "R",
            "dataNota": "2025-05-12 00:00:00.000",
            "fornecedor": "NEOALUMINIO IND. COM. DE METAIS LTDA",
            "situacao": "RESTO - 24/3000 - NEOALUMINIO IND. COM. DE METAIS LTDA"
        },
        {
            "produto": 10296,
            "produtoNome": "CABO AL.   DUPLEX 1X10+10,00MM XLPE PRETO C/ NEUTRO NU   (METRO) - 10296",
            "lote": "40377",
            "validade": "",
            "fabricacao": "",
            "ordem": 0,
            "quantidade": 34,
            "quantidadeNova": 34,
            "quantidadeEntrou": 3000,
            "quantidadeFabricado": 0,
            "obs": "R",
            "dataNota": "2025-05-12 00:00:00.000",
            "fornecedor": "NEOALUMINIO IND. COM. DE METAIS LTDA",
            "situacao": "RESTO - 34/3000 - NEOALUMINIO IND. COM. DE METAIS LTDA"
        },
        {
            "produto": 10296,
            "produtoNome": "CABO AL.   DUPLEX 1X10+10,00MM XLPE PRETO C/ NEUTRO NU   (METRO) - 10296",
            "lote": "40727",
            "validade": "",
            "fabricacao": "",
            "ordem": 0,
            "quantidade": 1800,
            "quantidadeNova": 1800,
            "quantidadeEntrou": 3000,
            "quantidadeFabricado": 0,
            "obs": "FC",
            "dataNota": "2025-06-09 00:00:00.000",
            "fornecedor": "COPPERFIO",
            "situacao": "USADO - 1800/3000 - COPPERFIO"
        }
    ],
    "techInfo": null
}

Request Pedido

Pedido/Get

Esse GET retorna um pedido inserido no sistema.

Parâmetro controle deve ser numérico. Representa a chave do pedido


    curl --location --request GET 'http://parema.com.br/apiv1/pedido/get?controle=[CONTROLE]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

    {
    "statusCode": 200,
    "message": "Pedido Encontrado",
    "content": [
        {
            "controle": 1111111111111,
            "cliente": {
                "codigo": 75899,
                "nome": "MARIA JOSE DA SILVA",
                "razaoSocial": "MARIA JOSE DA SILVA",
                "documento": "111.111.111-11",
                "documentoTipo": "CPF",
                "rg": "",
                "ie": "ISENTO",
                "im": "",
                "suframa": "",
                "dataNascimento": "1900-01-01T00:00:00",
                "sexo": "",
                "telefones": null,
                "email": "maria2000006421674006@testeteste.com",
                "endereco": {
                    "codigo": 0,
                    "nome": "Principal",
                    "endereco": "RUA PRINCIPAL DA CIDADE",
                    "complemento": "CASA",
                    "numero": "100",
                    "cidade": "VISCONDE DO RIO BRANCO",
                    "uf": "MG",
                    "cep": "36520-000",
                    "bairro": "CENTRO",
                    "pais": ""
                }
            },
            "data": "2023-09-12T00:00:00",
            "dataEmissao": "2023-09-12T10:54:56",
            "emissor": {
                "codigo": 1,
                "nome": "COMPUMATE SOFTWARES CORPORATIVOS LTDA",
                "razaoSocial": "COMPUMATE SOFTWARES CORPORATIVOS LTDA",
                "documento": "92.343.375/0001-72",
                "ie": "1111111111",
                "im": "",
                "dataFundacao": null,
                "dataCadastro": "2014-07-01T00:00:00",
                "dataAlt": "2025-03-11T11:17:03.56",
                "gerente": "",
                "endereco": {
                    "nome": "Principal",
                    "endereco": "RUA NENHUM",
                    "complemento": "",
                    "numero": "1000",
                    "cidade": "VENANCIO AIRES",
                    "uf": "RS",
                    "cep": "95800-000",
                    "bairro": "CENTRO",
                    "pais": "BRASIL"
                },
                "telefone": "(51) 3793-3500",
                "fax": "",
                "email": "richard@compumate.com.br",
                "homepage": ""
            },
            "nota": 97024,
            "serie": "1",
            "modeloNFE": 55,
            "modeloNFEDescricao": "NF-e",
            "origem": {
                "codigo": 35,
                "nome": "simplo7",
                "descricao": "Simplo7"
            },
            "cfop": "6108",
            "pedido": 89208,
            "pedidoCliente": "111111111",
            "pedidoCliente2": "xklm213213213",
            "statusPedido": 2,
            "statusPedidoData": "2023-09-12T10:54:54",
            "clienteObservacao":"Teste Observação",
            "nfeChave": "64564456456456456465645465456465",
            "valorNota": 619.8,
            "valorOutras": 0,
            "valorFrete": 0,
            "valorSeguro": 0,
            "valorServicos": 0,
            "valorFunrural": 0,
            "valorDesconto": 0,
            "valorAcrescimo": 0,
            "liberado": true,
            "condicaoPagamento": {
                "codigo": 18,
                "nome": "MERCADO LIVRE",
                "parcelas": 1
            },
            "transportador": {
                "codigo": 0,
                "nome": "",
                "documento": "",
                "rastreio": "97024",
                "rastreioLink": ""
            },
            "vendedor": {
                "codigo": 14,
                "nome": "TESTE",
                "razaoSocial": "TESTE",
                "documento": "__.___.___/____-__",
                "ativo": true,
                "supervisor": false,
                "endereco": {
                    "codigo": 0,
                    "nome": "Principal",
                    "endereco": "",
                    "complemento": "",
                    "numero": "",
                    "cidade": "LAJEADO",
                    "uf": "RS",
                    "cep": "95900-000",
                    "bairro": "",
                    "pais": "BRASIL"
                }
            },
            "enderecoCobranca": {
                "codigo": 106900,
                "nome": "MARIA JOSE DA SILVA",
                "endereco": "RUA PRINCIPAL DA CIDADE",
                "complemento": "CASA",
                "numero": "100",
                "cidade": "VISCONDE DO RIO BRANCO",
                "uf": "MG",
                "cep": "36520-000",
                "bairro": "CENTRO",
                "pais": "BRASIL"
            },
            "enderecoEntrega": {
                "codigo": 106900,
                "nome": "MARIA JOSE DA SILVA",
                "endereco": "RUA PRINCIPAL DA CIDADE",
                "complemento": "CASA",
                "numero": "100",
                "cidade": "VISCONDE DO RIO BRANCO",
                "uf": "MG",
                "cep": "36520-000",
                "bairro": "CENTRO",
                "pais": "BRASIL"
            },
            "statusPedidoHistorico": [
                {
                    "codigo": 19,
                    "automatico": 0,
                    "obs": "",
                    "nome": "ANYMARKET",
                    "dataalt": "2023-09-08T09:00:39"
                },
                {
                    "codigo": 30,
                    "automatico": 0,
                    "obs": "Alteração em Lote",
                    "nome": "AGUARDANDO EMISSÃO",
                    "dataalt": "2023-09-08T10:11:12"
                },
                {
                    "codigo": 2,
                    "automatico": 0,
                    "obs": "",
                    "nome": "FATURADO",
                    "dataalt": "2023-09-12T10:54:54"
                }
            ],
            "produtos": [
                {
                    "produto": 679,
                    "descricao": "300E - Aplique Muller Canga Envelhecido 300E",
                    "quantidade": 3,
                    "valorUnitario": 206.6,
                    "valorTotal": 619.8,
                    "valorDesconto": 0,
                    "item": 0
                }
            ]
        }
    ],
    "techInfo": null
}
    

Pedido/GetListOrigem

Esse GET retorna lista de tipos de Origem de um Pedido. Esse tipo pode ser repassado na consulta de lista de pedidos.


    curl --location --request GET 'http://parema.com.br/apiv1/pedido/getListOrigem' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

{
    "statusCode": 200,
    "message": "Itens Selecionados (43)",
    "content": [
        {
            "codigo": 1,
            "nome": "movimento",
            "descricao": "Movimento"
        },
        {
            "codigo": 2,
            "nome": "nota_Entrada",
            "descricao": "Nota de Entrada"
        },
        {
            "codigo": 3,
            "nome": "nota_Saida_Pedidos",
            "descricao": "Pedidos / Nota de Saída"
        },
        {
            "codigo": 4,
            "nome": "os",
            "descricao": "Ordem de Serviço"
        },
        {
            "codigo": 5,
            "nome": "orcamento",
            "descricao": "Orçamento"
        },
        {
            "codigo": 6,
            "nome": "pedido_Transferencia",
            "descricao": "Pedido Transferência"
        },
        {
            "codigo": 7,
            "nome": "pedido_Lojas",
            "descricao": "Pedido Lojas"
        },
        {
            "codigo": 8,
            "nome": "entrada_Cortume",
            "descricao": "Entrada Curtume"
        },
        {
            "codigo": 9,
            "nome": "pedido_Devolucao",
            "descricao": "Pedido de Devolução"
        },
        {
            "codigo": 10,
            "nome": "viagens_Turismo",
            "descricao": "Viagens (Turismo)"
        },
        {
            "codigo": 11,
            "nome": "servicos_Turismo",
            "descricao": "Serviços (Turismo)"
        },
        {
            "codigo": 12,
            "nome": "mensalidade_Sindicato",
            "descricao": "Mensalidade (Sindicato)"
        },
        {
            "codigo": 13,
            "nome": "fechamento_Caixa_Lehma",
            "descricao": "Fechamento dos Caixas do Lehma"
        },
        {
            "codigo": 14,
            "nome": "exportacao",
            "descricao": "Exportação"
        },
        {
            "codigo": 15,
            "nome": "comanda",
            "descricao": "Comanda"
        },
        {
            "codigo": 16,
            "nome": "trocaTroca_Sementes",
            "descricao": "Troca-Troca Sementes"
        },
        {
            "codigo": 17,
            "nome": "web_Pedidos",
            "descricao": "Web Pedidos"
        },
        {
            "codigo": 18,
            "nome": "pesagem_BomFrango",
            "descricao": "Pesagem Bom Frango"
        },
        {
            "codigo": 19,
            "nome": "conhecimento_CTe",
            "descricao": "Conhecimento (CT-e)"
        },
        {
            "codigo": 20,
            "nome": "assistencia_Tecnica",
            "descricao": "Assistência Técnica (Envio de produto para fábrica)"
        },
        {
            "codigo": 21,
            "nome": "imobiliaria",
            "descricao": "Imobiliária"
        },
        {
            "codigo": 22,
            "nome": "skyhub",
            "descricao": "Skyhub"
        },
        {
            "codigo": 23,
            "nome": "loteamento",
            "descricao": "Loteamento"
        },
        {
            "codigo": 24,
            "nome": "lojaIntegrada",
            "descricao": "Loja Integrada"
        },
        {
            "codigo": 25,
            "nome": "impNFServico",
            "descricao": "ImpNFServico"
        },
        {
            "codigo": 26,
            "nome": "wooCommerce",
            "descricao": "WooCommerce"
        },
        {
            "codigo": 27,
            "nome": "magento",
            "descricao": "Magento"
        },
        {
            "codigo": 28,
            "nome": "tray",
            "descricao": "Tray"
        },
        {
            "codigo": 29,
            "nome": "portomontt",
            "descricao": "Portomontt"
        },
        {
            "codigo": 30,
            "nome": "colombo",
            "descricao": "Colombo"
        },
        {
            "codigo": 31,
            "nome": "madeiraMadeira",
            "descricao": "Madeira Madeira"
        },
        {
            "codigo": 32,
            "nome": "xTech",
            "descricao": "XTech"
        },
        {
            "codigo": 33,
            "nome": "anyMarket",
            "descricao": "AnyMarket"
        },
        {
            "codigo": 34,
            "nome": "apiCompumateWeb",
            "descricao": "APICompumateWeb"
        },
        {
            "codigo": 35,
            "nome": "simplo7",
            "descricao": "Simplo7"
        },
        {
            "codigo": 36,
            "nome": "nuvemShop_TiendaNube",
            "descricao": "NuvemShop / TiendaNube"
        },
        {
            "codigo": 37,
            "nome": "livre37",
            "descricao": "LIVRE (Não usado)"
        },
        {
            "codigo": 38,
            "nome": "erpWeb",
            "descricao": "ERP Web"
        },
        {
            "codigo": 39,
            "nome": "appRural",
            "descricao": "APP Rural"
        },
        {
            "codigo": 40,
            "nome": "ifoodGroceryDelivery",
            "descricao": "iFood Grocery - Delivery"
        },
        {
            "codigo": 41,
            "nome": "ifoodGroceryTekeout",
            "descricao": "iFood Grocery - Takeout"
        },
        {
            "codigo": 42,
            "nome": "ifoodGroceryIndoor",
            "descricao": "iFood Grocery - Indoor"
        },
        {
            "codigo": -1,
            "nome": "nenhum",
            "descricao": "Nenhum"
        }
    ],
    "techInfo": null
}

Request Pedido Cliente

Pedido Cliente/Get

Esse GET retorna a lista de pedidos inseridos no sistema que possuem esse identificador de "PedidoCliente".

Parâmetro PedidoCliente deve ser alfanumérico. Representa a chave/id do pedido no sistema cliente.


    curl --location --request GET 'http://parema.com.br/apiv1/pedido/getPedidoCliente?pedidoCliente=[IDENTIFICADOR]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

    {
    "statusCode": 200,
    "message": "Pedido Encontrado",
    "content": [
        {
            "controle": 1111111111111,
            "cliente": {
                "codigo": 75899,
                "nome": "MARIA JOSE DA SILVA",
                "razaoSocial": "MARIA JOSE DA SILVA",
                "documento": "111.111.111-11",
                "documentoTipo": "CPF",
                "rg": "",
                "ie": "ISENTO",
                "im": "",
                "suframa": "",
                "dataNascimento": "1900-01-01T00:00:00",
                "sexo": "",
                "telefones": null,
                "email": "maria2000006421674006@testeteste.com",
                "endereco": {
                    "codigo": 0,
                    "nome": "Principal",
                    "endereco": "RUA PRINCIPAL DA CIDADE",
                    "complemento": "CASA",
                    "numero": "100",
                    "cidade": "VISCONDE DO RIO BRANCO",
                    "uf": "MG",
                    "cep": "36520-000",
                    "bairro": "CENTRO",
                    "pais": ""
                }
            },
            "data": "2023-09-12T00:00:00",
            "dataEmissao": "2023-09-12T10:54:56",
            "emissor": {
                "codigo": 1,
                "nome": "COMPUMATE SOFTWARES CORPORATIVOS LTDA",
                "razaoSocial": "COMPUMATE SOFTWARES CORPORATIVOS LTDA",
                "documento": "92.343.375/0001-72",
                "ie": "1111111111",
                "im": "",
                "dataFundacao": null,
                "dataCadastro": "2014-07-01T00:00:00",
                "dataAlt": "2025-03-11T11:17:03.56",
                "gerente": "",
                "endereco": {
                    "nome": "Principal",
                    "endereco": "RUA NENHUM",
                    "complemento": "",
                    "numero": "1000",
                    "cidade": "VENANCIO AIRES",
                    "uf": "RS",
                    "cep": "95800-000",
                    "bairro": "CENTRO",
                    "pais": "BRASIL"
                },
                "telefone": "(51) 3793-3500",
                "fax": "",
                "email": "richard@compumate.com.br",
                "homepage": ""
            },
            "nota": 97024,
            "serie": "1",
            "modeloNFE": 55,
            "modeloNFEDescricao": "NF-e",
            "cfop": "6108",
            "pedido": 89208,
            "pedidoCliente": "111111111",
            "pedidoCliente2": "xklm213213213",
            "statusPedido": 2,
            "statusPedidoData": "2023-09-12T10:54:54",
            "clienteObservacao":"Teste Observação",
            "nfeChave": "64564456456456456465645465456465",
            "valorNota": 619.8,
            "valorOutras": 0,
            "valorFrete": 0,
            "valorSeguro": 0,
            "valorServicos": 0,
            "valorFunrural": 0,
            "valorDesconto": 0,
            "valorAcrescimo": 0,
            "liberado": true,
            "condicaoPagamento": {
                "codigo": 18,
                "nome": "MERCADO LIVRE",
                "parcelas": 1
            },
            "vendedor": {
                "codigo": 14,
                "nome": "TESTE",
                "razaoSocial": "TESTE",
                "documento": "__.___.___/____-__",
                "ativo": true,
                "supervisor": false,
                "endereco": {
                    "codigo": 0,
                    "nome": "Principal",
                    "endereco": "",
                    "complemento": "",
                    "numero": "",
                    "cidade": "LAJEADO",
                    "uf": "RS",
                    "cep": "95900-000",
                    "bairro": "",
                    "pais": "BRASIL"
                }
            },
            "transportador": {
                "codigo": 0,
                "nome": "",
                "documento": "",
                "rastreio": "97024",
                "rastreioLink": ""
            },
            "enderecoCobranca": {
                "codigo": 106900,
                "nome": "MARIA JOSE DA SILVA",
                "endereco": "RUA PRINCIPAL DA CIDADE",
                "complemento": "CASA",
                "numero": "100",
                "cidade": "VISCONDE DO RIO BRANCO",
                "uf": "MG",
                "cep": "36520-000",
                "bairro": "CENTRO",
                "pais": "BRASIL"
            },
            "enderecoEntrega": {
                "codigo": 106900,
                "nome": "MARIA JOSE DA SILVA",
                "endereco": "RUA PRINCIPAL DA CIDADE",
                "complemento": "CASA",
                "numero": "100",
                "cidade": "VISCONDE DO RIO BRANCO",
                "uf": "MG",
                "cep": "36520-000",
                "bairro": "CENTRO",
                "pais": "BRASIL"
            },
            "statusPedidoHistorico": [
                {
                    "codigo": 19,
                    "automatico": 0,
                    "obs": "",
                    "nome": "ANYMARKET",
                    "dataalt": "2023-09-08T09:00:39"
                },
                {
                    "codigo": 30,
                    "automatico": 0,
                    "obs": "Alteração em Lote",
                    "nome": "AGUARDANDO EMISSÃO",
                    "dataalt": "2023-09-08T10:11:12"
                },
                {
                    "codigo": 2,
                    "automatico": 0,
                    "obs": "",
                    "nome": "FATURADO",
                    "dataalt": "2023-09-12T10:54:54"
                }
            ],
            "produtos": [
                {
                    "produto": 679,
                    "descricao": "300E - Aplique Muller Canga Envelhecido 300E",
                    "quantidade": 3,
                    "valorUnitario": 206.6,
                    "valorTotal": 619.8,
                    "valorDesconto": 0,
                    "item": 0
                }
            ]
        }
    ],
    "techInfo": null
}
    

Request Lista Pedido

Lista Pedido/Get

Esse GET retorna a lista de pedidos inseridos no sistema emitidos por um CNPJ para uma documento de cliente (CPF/CNPJ).

Parâmetro emissorDocumento documento do emissor, preferencialmente sem formatação.

Parâmetro clienteDocumento documento do cliente, preferencialmente sem formatação.

Parâmetro dataInicial data no formato abaixo. Exemplo (2024-12-01) (opcional).

Parâmetro dataFinal documento do formato abaixo. Exemplo (2024-12-01) (opcional).

Parâmetro tipoOrigem número inteiro ou nome. Exemplo (35) ou (simplo7) (opcional).

Parâmetro data deve ser no formato YYYY-MM-DDThh:mm:ss.fff ex: 2021-01-29T07:55:46.757

Parâmetro data deve ser no formato YYYY-MM-DDThh:mm:ss ex: 2021-01-29T07:55:46

Parâmetro data deve ser no formato YYYY-MM-DD ex: 2021-01-29

Parâmetro datainicial é opcional


    curl --location --request GET 'http://parema.com.br/apiv1/pedido/getListaPedido?emissorDocumento=[EMISSOR_DOCUMENTO]&clienteDocumento=[CLIENTE_DOCUMENTO]&datainicial=[DATA_INICIAL]&datafinal=[DATA_FINAL]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Incluir Pedido

Pedido/Post

Esse POST cadastra um pedido no sistema.


    curl --location --request POST 'http://parema.com.br/apiv1/pedido/add' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Exemplo de Post para inclusão de Pedido

Atributo Pedido.Pedido você deve ir incrementando para a inclusão de novos pedidos

Atributo Pedido.Cliente será cadastrado no sistema, caso não existir, automaticamente. O campo chave é o documento.

Atributo Pedido.enderecoEntrega não é obrigatório, mas é recomendado. Esse endereço é para onde o produto / encomenda / nota deverá ser enviado.

Atributo Pedido.enderecoCobranca não é obrigatório, mas é recomendado. Esse endereço é para onde os dados e documento de faturamento ee ou cobrança deverão ser enviados.

Caso nenhum endereço for preenchido, será usado o Pedido.Cliente.Endereco. Caso esse usuário faça 2 pedidos com endereços diferentes e caso os pedidos sejam faturados no mesmo momento, ambos os pedidos serão validados com o endereço do último pedido adicionado.


    {
	"cliente":{
		"nome":"Fulano de Tal",
		"documento":"90584903006",
		"documentoTipo":"CPF",
		"rg":"259334868",
		"ie":"",
		"im":"",
		"suframa":"",
		"dataNascimento":"1981-01-01",
		"sexo":"",
		"telefones":
		[
			{
				"contato":"Zé Fulano",
				"telefone":"51999998877",
				"movel":true
			},
			{
				"contato":"Zé Fulano",
				"telefone":"5137939999",
				"movel":false
			}
		],
		"email":"fulano@email.com.br",
		"endereco":{
			"nome":"Casa",
			"endereco":"Jacob Becker",
			"complemento":"Casa",
			"numero":"1824",
			"cidade":"Venâncio Aires",
			"uf":"RS",
			"cep":"95800-000",
			"bairro":"Centro",
			"pais":"Brasil"
		}
	},
	"clienteObservacao":"Teste Observação",
	"enderecoEntrega":{
		"nome":"Empresa",
		"endereco":"Rua Emílio Selbach",
		"complemento":"compumate",
		"numero":"825",
		"cidade":"Venâncio Aires",
		"uf":"RS",
		"cep":"95800-000",
		"bairro":"Centro",
		"pais":"Brasil"
	},
	"enderecoCobranca":{
		"nome":"Casa",
		"endereco":"Jacob Becker",
		"complemento":"Casa",
		"numero":"1824",
		"cidade":"Venâncio Aires",
		"uf":"RS",
		"cep":"95800-000",
		"bairro":"Centro",
		"pais":"Brasil"
	},
	"pedido":"TESTE-001",
	"dataCriacao":"2021-03-01T01:00:01.123",
	"dataModificacao":"2021-03-01T01:00:01.123",
	"formaPagamento":{
		"descricao":"BOLETO",
		"parcelas":1,
		"idTransacao":"ID-8123782178397821973",
		"data":"2021-03-01T01:00:01.123",
		"obs":"observação no boleto - não imprime"
	}
	"cupom":"cupom5";
	"valorDesconto":.0,
	"valorAcrescimo":.0,
	"valorFrete":350.00,
	"valorTotal":5000.59,
	"itens":[
		{
			"codigo":22,
			"descricao":"EXPOSITORA DE BEBIDAS VVCD 200L AMARELA 127 V",
			"quantidade":1.0,
            "unidade": "UN",
			"unitario":2949.0,
			"total":2899.0,
			"desconto":50.0			
		}
	],
    "transportador": {
        "nome": "Correio PAC",
        "prazo": "18\/03\/2024 00:00:00",
        "obs": null,
        "rastreio": "12345",
        "rastreioLink":"http://"
    }
}

Atributo Pedido.filial não é obrigatório. Quando não utilizado, o sistema irá usar por padrão a filial configurado no sistema para inclusão de pedidos.


    {
    "filial":1,
	"cliente":{
		"nome":"Fulano de Tal",
		"documento":"90584903006",
		"documentoTipo":"CPF",
		"rg":"259334868",
		...
    ...
    }
}

Request do XML Nfe

Pedido/getXML

Esse GET retorna o arquivo XML da nota fiscal referente ao pedido, caso tenha sido emitida

Parâmetro controle do pedido deve ser numérico


    curl --location --request GET 'http://parema.com.br/apiv1/pedido/getXML?controle=[CONTROLE_PEDIDO]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Pedido/getXMLLink

Esse GET retorna um objeto json que contém o link do arquivo XML da nota fiscal referente ao pedido, caso tenha sido emitida

Parâmetro controle do pedido deve ser numérico


    curl --location --request GET 'http://parema.com.br/apiv1/pedido/getXMLLink?controle=[CONTROLE_PEDIDO]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Request do PDF Nfe

Pedido/getPDF

Esse GET retorna o arquivo PDF da nota fiscal referente ao pedido, caso tenha sido emitida

Parâmetro controle do pedido deve ser numérico


    curl --location --request GET 'http://parema.com.br/apiv1/pedido/getPDF?controle=[CONTROLE_PEDIDO]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Pedido/getPDFLink

Esse GET retorna um objeto json que contém o link do arquivo PDF da nota fiscal referente ao pedido, caso tenha sido emitida

Parâmetro controle do pedido deve ser numérico


    curl --location --request GET 'http://parema.com.br/apiv1/pedido/getPDFLink?controle=[CONTROLE_PEDIDO]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Request do PDF Boleto

Pedido/getBoleto

Esse GET retorna o arquivo PDF do boleto referente ao pedido, caso tenha sido emitido

Parâmetro controle do pedido deve ser numérico


    curl --location --request GET 'http://parema.com.br/apiv1/pedido/getBoleto?controle=[CONTROLE_PEDIDO]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Pedido/getBoletoParcelab

Esse GET retorna o arquivo PDF da parcela do boleto referente ao pedido, caso tenha sido emitido

Parâmetro controle do pedido deve ser numérico


    curl --location --request GET 'http://parema.com.br/apiv1/pedido/getBoletoParcela?controle=[CONTROLE_PARCELA]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Pedido/getBoletoLink

Esse GET retorna um objeto json que contém o link do arquivo PDF do boleto referente ao pedido, caso tenha sido emitido

Parâmetro controle do pedido deve ser numérico


    curl --location --request GET 'http://parema.com.br/apiv1/pedido/getBoletoLink?controle=[CONTROLE_PEDIDO]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Pedido/getBoletoParcelaLink

Esse GET retorna um objeto json que contém o link do arquivo PDF da parcela do boleto referente ao pedido, caso tenha sido emitido

Parâmetro controle do pedido deve ser numérico


    curl --location --request GET 'http://parema.com.br/apiv1/pedido/getBoletoParcelaLink?controle=[CONTROLE_PARCELA]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Status Pedido

PedidoStatus/Cancelar

Esse POST cancela (remove) um pedido caso ele ainda não tenha sido liberado ou troca o status do pedido para cancelado (dependendo das configurações) caso ele já tenha sido liberaod.

Parâmetro controle do pedido deve ser numérico

Parâmetro observacao do status (Opcional)


    curl --location --request GET 'http://parema.com.br/apiv1/pedidostatus/cancelar?controle=[CONTROLE_PEDIDO]&observacao=[TEXTO_OBSERVAÇÃO_OPCIONAL]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Listar Cliente(s) com modificação

Cliente/List

Esse GET retorna uma lista com os dados de cliente(s)/forncedor(s) modificados.

Parâmetro opcional ativo usado para filtragem dos dados.

Parâmetro opcional dataInicial usado para filtragem dos dados. Filtra lista a partir desta data de modificação.

Parâmetro dataFinal usado para filtragem dos dados. Filtra lista até desta data de modificação.


    curl --location --request GET 'http://parema.com.br/apiv1/cliente/list' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

    curl --location --request GET 'http://parema.com.br/apiv1/cliente/list?ativo=true&dataInicial=2025-10-01&dataFinal=2026-03-30T23:59:58.999' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Exemplo de Get para consulta de lista de cliente fornecedor modificados


    {
        "statusCode": 200,
        "message": "OK",
        "content": [
            {
                "codigo": 10001,
                "nome": "NOME 10001",
                "razaoSocial": "RAZAO SOCIAL 10001",
                "documento": "111.111.111-11",
                "ativo": true,
                "dataRevisaoCadastro": null,
                "dataAlt": "2026-01-28T14:50:45.467"
            },
            {
                "codigo": 10002,
                "nome": "NOME 10002",
                "razaoSocial": "RAZAO SOCIAL 10002",
                "documento": "22.222.222/0001-22",
                "ativo": false,
                "dataRevisaoCadastro": "2023-03-03T17:28:20.167",
                "dataAlt": "2023-03-03T17:28:20.167"
            },
            ...,
            {
                "codigo": 10013,
                "nome": "NOME 10013",
                "razaoSocial": "RAZAO SOCIAL 10013",
                "documento": "33.333.333/0001-33",
                "ativo": true,
                "dataRevisaoCadastro": null,
                "dataAlt": "2026-03-12T10:54:29.18"
            }
        ],
        "techInfo": null
    }

Consultar Cliente(s)

Cliente/Get?codigo=XXXX

Esse GET retorna os dados de um cliente/forncedor.

Parâmetro codigo do cliente/fornecedor, preferencialmente sem formatação.


    curl --location --request GET 'http://parema.com.br/apiv1/cliente/get?codigo=[CODIGO_DO_CLIENTE]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Exemplo de Get para consulta de cliente fornecedor


    {
        "statusCode": 200,
        "message": "OK",
        "content": {
            "codigo": 999,
            "razaoSocial": "RAZAO SOCIAL LTDA",
            "nome": "NOME FANTASIA",
            "documento": "99.999.999/0001-99",
            "rg": "",
            "ie": "509999999999",
            "im": "",
            "observacoes": "OBSERVAÇÕES DO CADATROS",
            "email": [
                {
                    "email": "emaildaempresa@empresa.com",
                    "contato": "",
                    "tipo": "Comercial"
                },
                {
                    "email": "emaildaempresa@empresa.com",
                    "contato": "",
                    "tipo": "Compras"
                },
                {
                    "email": "emaildaempresa@empresa.com",
                    "contato": "",
                    "tipo": "CT-e"
                },
                {
                    "email": "emaildaempresa@empresa.com",
                    "contato": "",
                    "tipo": "Financeiro"
                },
                {
                    "email": "emaildaempresa@empresa.com",
                    "contato": "",
                    "tipo": "NF-e"
                },
                {
                    "email": "emaildaempresa@empresa.com",
                    "contato": "",
                    "tipo": "Outros"
                }
            ],
            "fone": [
                {
                    "ddi": "51",
                    "ddd": "+55",
                    "fone": "3793-3500",
                    "contato": "",
                    "tipo": "Comercial"
                },
                {
                    "ddi": "51",
                    "ddd": "+55",
                    "fone": "3793-3500",
                    "contato": "",
                    "tipo": "CT-e"
                },
                {
                    "ddi": "51",
                    "ddd": "+55",
                    "fone": "3793-3500",
                    "contato": "",
                    "tipo": "Financeiro"
                },
                {
                    "ddi": "51",
                    "ddd": "+55",
                    "fone": "3793-3500",
                    "contato": "",
                    "tipo": "NF-e"
                },
                {
                    "ddi": "51",
                    "ddd": "+55",
                    "fone": "3793-3500",
                    "contato": "",
                    "tipo": "WhatsApp"
                }
            ],
            "endereco": {
                "nome": "NOME FANTASIA",
                "endereco": "RUA RUA RUA RUA RUA",
                "complemento": "CASA REFERENCIA: ATRÁS DO CEMITÉRIO",
                "numero": "10",
                "cidade": "VENANCIO AIRES",
                "uf": "RS",
                "cep": "95800-000",
                "bairro": "CENTRO",
                "pais": "BRASIL",
                "homepage": "",
                "longitude": 0.0,
                "latitude": 0.0,
                "dataalt": "2024-10-10T19:28:37.287"
            },
            "enderecoEntrega": {
                "codigo": 4000,
                "entrega": true,
                "cobranca": false,
                "redespacho": false,
                "fone": "",
                "email": "",
                "observacoes": "",
                "nome": "NOME FANTASIA",
                "endereco": "RUA RUA RUA RUA RUA",
                "complemento": "CASA REFERENCIA: ATRÁS DO CEMITÉRIO",
                "numero": "10",
                "cidade": "VENANCIO AIRES",
                "uf": "RS",
                "cep": "95800-000",
                "bairro": "CENTRO",
                "pais": "BRASIL",
                "homepage": "",
                "longitude": 0.0,
                "latitude": 0.0,
                "dataalt": "2024-08-03T07:20:49.4"
            },
            "enderecoCobranca": {
                "codigo": 3982,
                "entrega": true,
                "cobranca": false,
                "redespacho": false,
                "fone": "",
                "email": "",
                "observacoes": "",
                "nome": "NOME FANTASIA",
                "endereco": "RUA RUA RUA RUA RUA",
                "complemento": "CASA REFERENCIA: ATRÁS DO CEMITÉRIO",
                "numero": "10",
                "cidade": "VENANCIO AIRES",
                "uf": "RS",
                "cep": "95800-000",
                "bairro": "CENTRO",
                "pais": "BRASIL",
                "homepage": "",
                "longitude": 0.0,
                "latitude": 0.0,
                "dataalt": "2024-08-03T07:20:49.4"
            },
            "enderecoRedespacho": null,
            "dataNascimento": "0001-01-01T00:00:00",
            "dataCadastro": "2024-08-03T00:00:00",
            "dataRevisaoCadastro": "2024-08-05T00:00:00",
            "ativo": true
        },
        "techInfo": null
    }

Cliente/GetDocumento?documento=XXXXXXXXXXX

Esse GET retorna uma array com os dados de clientes/forncedores que possuem este documento. Nesse caso é um array pois o sistema legado suportava duplicidade de documento

Parâmetro documento do cliente/fornecedor, CPF CNPJ, preferencialmente sem formatação.


    curl --location --request GET 'http://parema.com.br/apiv1/cliente/getdocumento?documento=[DOCUMENTO_DO_CLIENTE]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'


    {
        "statusCode": 200,
        "message": "OK",
        "content": [{
            "codigo": 999,
            "razaoSocial": "RAZAO SOCIAL LTDA",
            "nome": "NOME FANTASIA",
            "documento": "99.999.999/0001-99",
            "rg": "",
            "ie": "509999999999",
            "im": "",
            .......
        },
        {
            "codigo": 1000,
            "razaoSocial": "RAZAO SOCIAL LTDA",
            "nome": "NOME FANTASIA",
            "documento": "99.999.999/0001-99",
            "rg": "",
            "ie": "509999999999",
            "im": "",
            .......
        }],
        "techInfo": null
    }

Endereços Adicionais

EnderecoAdicional/list?cliente=XXXXXXXXXXX

Esse GET retorna uma array com os dados de endereços alternativos de clientes/forncedores.

Parâmetro cliente é o código do cliente/fornecedor.


    curl --location --request GET 'http://parema.com.br/apiv1/EnderecoAdicional/list?cliente=[CODIGO_CLIENTE]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'


    {
    "statusCode": 200,
    "message": "OK",
    "content": [
        {
            "codigo": 1000,
            "entrega": true,
            "cobranca": false,
            "redespacho": false,
            "fone": "",
            "email": "",
            "observacoes": "",
            "nome": "NOME DA EMPRESA LTDA",
            "endereco": "GUILHERME ELLWANGUER",
            "complemento": "",
            "numero": "1",
            "cidade": "PAROBE",
            "uf": "RS",
            "cep": "95630-000",
            "bairro": "LARANJEIRA",
            "pais": "BRASIL",
            "homepage": "",
            "longitude": 0.0,
            "latitude": 0.0,
            "dataalt": "2021-09-30T19:38:30.983"
        },
        {
            "codigo": 1001,
            "entrega": true,
            "cobranca": false,
            "redespacho": false,
            "fone": "",
            "email": "",
            "observacoes": "",
            "nome": "canela",
            "endereco": "PATRICIO ZINI SOBRINHO",
            "complemento": "",
            "numero": "1",
            "cidade": "CANELA",
            "uf": "RS",
            "cep": "95630-000",
            "bairro": "CELULOSE",
            "pais": "BRASIL",
            "homepage": "",
            "longitude": 0.0,
            "latitude": 0.0,
            "dataalt": "2024-07-30T17:07:44.643"
        },
        {
            "codigo": 1002,
            "entrega": true,
            "cobranca": false,
            "redespacho": false,
            "fone": "",
            "email": "",
            "observacoes": "",
            "nome": "casa",
            "endereco": "DENEVAL XXXXXX XXXXX ",
            "complemento": "",
            "numero": "1",
            "cidade": "PAROBE",
            "uf": "RS",
            "cep": "95630-000",
            "bairro": "COLINA DO LEAO",
            "pais": "BRASIL",
            "homepage": "",
            "longitude": 0.0,
            "latitude": 0.0,
            "dataalt": "2024-10-23T17:37:13.947"
        }
    ],
    "techInfo": null
}

EnderecoAdicional/list?documento=XXX.XXX.XXX-XX

Esse GET retorna uma array com os dados de endereços alternativos de clientes/forncedores.

Parâmetro documento é o documento do cliente/fornecedor.


    curl --location --request GET 'http://parema.com.br/apiv1/EnderecoAdicional/list?documento=[DOCUMENTO]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'


    {
    "statusCode": 200,
    "message": "OK",
    "content": [
        {
            "codigo": 1000,
            "entrega": true,
            "cobranca": false,
            "redespacho": false,
            "fone": "",
            "email": "",
            "observacoes": "",
            "nome": "NOME DA EMPRESA LTDA",
            "endereco": "GUILHERME ELLWANGUER",
            "complemento": "",
            "numero": "1",
            "cidade": "PAROBE",
            "uf": "RS",
            "cep": "95630-000",
            "bairro": "LARANJEIRA",
            "pais": "BRASIL",
            "homepage": "",
            "longitude": 0.0,
            "latitude": 0.0,
            "dataalt": "2021-09-30T19:38:30.983"
        },
        {
            "codigo": 1001,
            "entrega": true,
            "cobranca": false,
            "redespacho": false,
            "fone": "",
            "email": "",
            "observacoes": "",
            "nome": "canela",
            "endereco": "PATRICIO ZINI SOBRINHO",
            "complemento": "",
            "numero": "1",
            "cidade": "CANELA",
            "uf": "RS",
            "cep": "95630-000",
            "bairro": "CELULOSE",
            "pais": "BRASIL",
            "homepage": "",
            "longitude": 0.0,
            "latitude": 0.0,
            "dataalt": "2024-07-30T17:07:44.643"
        },
        {
            "codigo": 1002,
            "entrega": true,
            "cobranca": false,
            "redespacho": false,
            "fone": "",
            "email": "",
            "observacoes": "",
            "nome": "casa",
            "endereco": "DENEVAL XXXXXX XXXXX ",
            "complemento": "",
            "numero": "1",
            "cidade": "PAROBE",
            "uf": "RS",
            "cep": "95630-000",
            "bairro": "COLINA DO LEAO",
            "pais": "BRASIL",
            "homepage": "",
            "longitude": 0.0,
            "latitude": 0.0,
            "dataalt": "2024-10-23T17:37:13.947"
        }
    ],
    "techInfo": null
}

Endereços Adicionais

EnderecoAdicional/get?codigo=XXXXXXXXXXX

Esse GET retorna os dados de um endereços alternativos de clientes/forncedores.

Parâmetro codigo é o código do endereço.


    curl --location --request GET 'http://parema.com.br/apiv1/EnderecoAdicional/get?codigo=[CODIGO_ENDERECO]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'


    {
    "statusCode": 200,
    "message": "OK",
    "content": {
        "codigo": 11111,
        "entrega": true,
        "cobranca": false,
        "redespacho": false,
        "fone": "",
        "email": "",
        "observacoes": "",
        "nome": "XXXXXXXXX XXXXXXX LTDA",
        "endereco": "RUA 7 DE SETEMBRO",
        "complemento": "",
        "numero": "11111",
        "cidade": "VENANCIO AIRES",
        "uf": "RS",
        "cep": "95800-000",
        "bairro": "CENTRO",
        "pais": "BRASIL",
        "homepage": "",
        "longitude": 0.0,
        "latitude": 0.0,
        "dataalt": "2022-09-27T09:58:22.28"
    },
    "techInfo": null
}

Listar Vendedor / Representante (s) com modificação

Vendedor/List

Esse GET retorna uma lista com os dados de vendedor(es)/representante(s) modificados.

Parâmetro opcional ativo usado para filtragem dos dados.

Parâmetro opcional dataInicial usado para filtragem dos dados. Filtra lista a partir desta data de modificação.

Parâmetro opcional dataFinal usado para filtragem dos dados. Filtra lista até esta data de modificação.

Parâmetro opcional vendedor usado para filtragem dos dados.

Parâmetro opcional comprador usado para filtragem dos dados.

Parâmetro opcional mecanico usado para filtragem dos dados.

Parâmetro opcional comissionado usado para filtragem dos dados.

Parâmetro opcional instalador usado para filtragem dos dados.

Parâmetro opcional motorista usado para filtragem dos dados.

Parâmetro opcional contato usado para filtragem dos dados.

Parâmetro opcional gerente usado para filtragem dos dados.

Parâmetro opcional tecnico usado para filtragem dos dados.

Parâmetro opcional lojista usado para filtragem dos dados.

Parâmetro opcional motoristaAux usado para filtragem dos dados.

Parâmetro opcional coordenador usado para filtragem dos dados.

Parâmetro opcional atendente usado para filtragem dos dados.


    curl --location --request GET 'http://parema.com.br/apiv1/vendedor/list' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

    curl --location --request GET 'http://parema.com.br/apiv1/vendedor/list?ativo=true&dataInicial=2025-10-01&dataFinal=2026-03-30T23:59:58.999' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

    curl --location --request GET 'http://parema.com.br/apiv1/vendedor/list?ativo=true&comprador=true&gerente=true' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

    curl --location --request GET 'http://parema.com.br/apiv1/vendedor/list?ativo=true&dataInicial=2025-10-01&dataFinal=2026-03-30T23:59:58.999&vendedor=true&tecnico=false' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Exemplo de Get para consulta de lista de vendedor / representante modificados


    {
    "statusCode": 200,
    "message": "OK",
    "content": [
        {
            "codigo": 1,
            "nome": "JOANA",
            "razaoSocial": "",
            "documento": "__.___.___/____-__",
            "ativo": false,
            "dataAlt": "2019-11-07T09:27:01.853"
        },
        {
            "codigo": 2,
            "nome": "SKYHUB",
            "razaoSocial": "",
            "documento": "__.___.___/____-__",
            "ativo": true,
            "dataAlt": "2019-11-05T17:23:42.733"
        },
        ...,
        {
            "codigo": 107,
            "nome": "CASSIO",
            "razaoSocial": "CASSIO",
            "documento": "111.111.111-11",
            "ativo": true,
            "dataAlt": "2024-08-28T09:37:24.317"
        }
    ],
    "techInfo": null
}

Detalhes do Vendedor / Representante

Cliente/Get

Esse GET retorna os detalhes de um vendedor/representante.

Parâmetro Codigo do cliente no sistema compumate.


    curl --location --request GET 'http://parema.com.br/apiv1/vendedor/get?codigo=1' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Exemplo de Get para consulta de vendedor / representante


    {
    "statusCode": 200,
    "message": "OK",
    "content": {
        "codigo": 1,
        "razaoSocial": "",
        "nome": "JOANA",
        "documento": "__.___.___/____-__",
        "rg": "",
        "ie": "",
        "observacoes": "",
        "contato": "",
        "email": {
            "email": "email@gmail.com",
            "contato": "",
            "tipo": ""
        },
        "fone": {
            "ddi": "",
            "ddd": "",
            "fone": "",
            "contato": "",
            "tipo": "Telefone"
        },
        "fax": {
            "ddi": "",
            "ddd": "",
            "fone": "",
            "contato": "",
            "tipo": "Fax"
        },
        "endereco": {
            "nome": "JOANA",
            "endereco": "",
            "complemento": "",
            "numero": "",
            "cidade": "LAJEADO",
            "uf": "RS",
            "cep": "95900-000",
            "bairro": "",
            "pais": "BRASIL",
            "homepage": "",
            "longitude": 0,
            "latitude": 0,
            "dataalt": "2019-11-07T09:27:01.853"
        },
        "filial": {
            "codigo": 0,
            "nome": "Nenhuma"
        },
        "ativo": true,
        "tipoCadastro": {
            "vendedor": true,
            "comprador": false,
            "mecanico": false,
            "comissionado": false,
            "instalador": false,
            "motorista": false,
            "contato": false,
            "gerente": false,
            "tecnico": false,
            "lojista": false,
            "motoristaAux": false,
            "coordenador": false,
            "atendente": false
        },
        "naturalidade": "",
        "nacionalidade": "",
        "dataNascimento": "0001-01-01T00:00:00"
    },
    "techInfo": null
}

Detalhes do Vendedor / Representante por documento

Vendedor/GetDocumento

Esse GET retorna um array com detalhes de vendedor/representante. Nesse caso é um array pois o sistema legado suportava duplicidade de documento.

Parâmetro Documento do vendedor / representante no sistema compumate.


    curl --location --request GET 'http://parema.com.br/apiv1/vendedor/getdocumento?documento=111.111.111-11' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'

Exemplo de Get para consulta de vendedor / representante por documento


    {
    "statusCode": 200,
    "message": "OK",
    "content": [
        {
        "codigo": 5,
        "razaoSocial": "",
        "nome": "FELIPE",
        "documento": "111.111.111-11",
        "rg": "",
        "ie": "",
        "observacoes": "",
        "contato": "",
        "email": {
            "email": "email@gmail.com",
            "contato": "",
            "tipo": ""
        },
        "fone": {
            "ddi": "",
            "ddd": "",
            "fone": "",
            "contato": "",
            "tipo": "Telefone"
        },
        "fax": {
            "ddi": "",
            "ddd": "",
            "fone": "",
            "contato": "",
            "tipo": "Fax"
        },
        "endereco": {
            "nome": "JOANA",
            "endereco": "",
            "complemento": "",
            "numero": "",
            "cidade": "LAJEADO",
            "uf": "RS",
            "cep": "95900-000",
            "bairro": "",
            "pais": "BRASIL",
            "homepage": "",
            "longitude": 0,
            "latitude": 0,
            "dataalt": "2019-11-07T09:27:01.853"
        },
        "filial": {
            "codigo": 0,
            "nome": "Nenhuma"
        },
        "ativo": true,
        "tipoCadastro": {
            "vendedor": true,
            "comprador": false,
            "mecanico": false,
            "comissionado": false,
            "instalador": false,
            "motorista": false,
            "contato": false,
            "gerente": false,
            "tecnico": false,
            "lojista": false,
            "motoristaAux": false,
            "coordenador": false,
            "atendente": false
        },
        "naturalidade": "",
        "nacionalidade": "",
        "dataNascimento": "0001-01-01T00:00:00"
    }
    ],
    "techInfo": null
}

SQL Customizado

SQL/Query?consulta=[CODIGO DA CONSULTA]

Esse GET retorna os dados em formato JSON.

Parâmetro consulta é o código da consulta SQL (Obtido depois de cadastrar o comando).

Essas consultas SQL precisam ser "cadastradas" na tela de configuração de API dentro do Sistema Compumate.

Parâmetro para dar replace é um objeto json que deve estar no body da mensagem.


    curl --location --request GET 'http://parema.com.br/apiv1/SQL/Query?consulta=[CODIGO_DA_CONTULTA]' \
    --header 'Authorization: Bearer [TOKEN GERADO NA ETAPA REQUEST TOKEN]'
    --data '{
        "replace1": "3998",
        "outrodado": "DDDDD"
    }'